<?php

namespace Futage\Live\Policies;

use Litepie\User\Contracts\UserPolicy;
use Futage\Live\Models\Live;

class LivePolicy
{

    /**
     * Determine if the given user can view the live.
     *
     * @param UserPolicy $user
     * @param Live $live
     *
     * @return bool
     */
    public function view(UserPolicy $user, Live $live)
    {
        if ($user->canDo('live.live.view') && $user->isAdmin()) {
            return true;
        }

        return $live->user_id == user_id() && $live->user_type == user_type();
    }

    /**
     * Determine if the given user can create a live.
     *
     * @param UserPolicy $user
     * @param Live $live
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('live.live.create');
    }

    /**
     * Determine if the given user can update the given live.
     *
     * @param UserPolicy $user
     * @param Live $live
     *
     * @return bool
     */
    public function update(UserPolicy $user, Live $live)
    {
        if ($user->canDo('live.live.edit') && $user->isAdmin()) {
            return true;
        }

        return $live->user_id == user_id() && $live->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given live.
     *
     * @param UserPolicy $user
     * @param Live $live
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Live $live)
    {
        return $live->user_id == user_id() && $live->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given live.
     *
     * @param UserPolicy $user
     * @param Live $live
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Live $live)
    {
        if ($user->canDo('live.live.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given live.
     *
     * @param UserPolicy $user
     * @param Live $live
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Live $live)
    {
        if ($user->canDo('live.live.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
